import A2ZLogo from "./A2ZLogo";
import { ChevronDown, ArrowRight, Star, CheckCircle, Calendar, Phone, Award, Shield } from "lucide-react";
import { useEffect, useState, memo } from "react";
import { motion } from "framer-motion";

export default function HeroSection() {
  const [scrollY, setScrollY] = useState(0);
  const [isMobile, setIsMobile] = useState(true); // Default to mobile for fastest initial render

  useEffect(() => {
    const checkMobile = () => {
      const mobile = window.innerWidth <= 768;
      setIsMobile(mobile);
      return mobile;
    };
    
    const mobile = checkMobile();
    
    // Enable smooth parallax on desktop after initial load
    if (!mobile) {
      let ticking = false;
      const handleScroll = () => {
        if (!ticking) {
          requestAnimationFrame(() => {
            setScrollY(window.scrollY);
            ticking = false;
          });
          ticking = true;
        }
      };
      
      window.addEventListener("scroll", handleScroll, { passive: true });
      window.addEventListener('resize', checkMobile);
      
      return () => {
        window.removeEventListener("scroll", handleScroll);
        window.removeEventListener('resize', checkMobile);
      };
    }
    
    window.addEventListener('resize', checkMobile);
    return () => window.removeEventListener('resize', checkMobile);
  }, []);

  return (
    <section id="hero" className="hero-section relative min-h-screen flex items-center justify-center overflow-hidden">
      {/* Background image with parallax effect and overlay */}
      <div className="absolute inset-0 z-0">
        <img 
          src="/images/gallery/b070a687-1f96-46ad-9818-4c41136a5241.webp" 
          alt="Modern luxury kitchen with premium white stone countertops and waterfall island" 
          className="w-full h-full object-cover hero-image"
          style={{ 
            transform: isMobile ? 'none' : `translate3d(0, ${scrollY * 0.3}px, 0) scale(${1 + scrollY * 0.0002})`,
            filter: isMobile ? 'none' : `brightness(${1 - scrollY * 0.0005})`
          }}
          loading="eager"
          decoding="async"
          width="1920"
          height="1080"
        />
        {/* Enhanced gradient overlay with parallax */}
        <div 
          className="absolute inset-0 bg-gradient-to-br from-black/80 via-black/60 to-black/40"
          style={{
            transform: isMobile ? 'none' : `translate3d(0, ${scrollY * 0.1}px, 0)`,
            opacity: isMobile ? 1 : Math.max(0.4, 1 - scrollY * 0.001)
          }}
        ></div>
        
        {/* Removed floating particles for better performance */}

      </div>
      
      {/* Hero content with parallax */}
      <div className="container mx-auto px-4 z-10 text-center min-h-screen flex items-center">
        <div 
          className={`mx-auto max-w-5xl ${isMobile ? '' : 'animate-fade-in'}`}
          style={{
            transform: isMobile ? 'none' : `translate3d(0, ${scrollY * -0.15}px, 0)`,
            opacity: isMobile ? 1 : Math.max(0.1, 1 - scrollY * 0.002)
          }}
        >

          <h1 className="hero-title">
            <span className="hero-title-line">Transform Your Home with</span>
            <span className="hero-title-accent">Premium Stone Countertops</span>
          </h1>
          



          
          <div className="flex flex-col gap-4 sm:flex-row sm:gap-6 justify-center items-stretch sm:items-center mb-10 sm:mb-12 w-full max-w-sm mx-auto sm:max-w-none px-4 sm:px-0">
            <a
              href="#contact"
              className="hero-btn-primary"
            >
              <Calendar className="h-5 w-5" />
              Book Free Consultation
            </a>
            
            <a
              href="tel:+1-647-561-8084"
              className="hero-btn-secondary"
            >
              <Phone className="h-5 w-5" />
              (647) 561-8084
            </a>
          </div>

          {/* Social Proof */}
          <div className="hero-stats">
            <div className="hero-stat">
              <span className="hero-stat-number">500+</span> Projects Completed
            </div>
            <div className="hero-stat">
              <span className="hero-stat-number">15+ Years</span> Experience
            </div>
          </div>
        </div>
      </div>
      

    </section>
  );
}
